from awesome_progress_bar import ProgressBar
import time

total = 133
bar = ProgressBar(total)
try:
    for x in range(total):
        time.sleep(0.1)
        bar.iter()
except:
    bar.stop()
bar.wait()
time_passed = bar.get_time_passed()
print(f'Total time passed: {time_passed}')
# Progress: |==================================== 00:15 =====================================| 100.00%
# Total time passed: 00:15

bar = ProgressBar(total, 'Prefix', 'Suffix', use_eta=True)
try:
    for x in range(total):
        time.sleep(0.1)
        bar.iter()
except:
    bar.stop()
bar.wait()
time_passed = bar.get_time_passed(False)
print(f'Total seconds passed: {time_passed:.4f}')
# Prefix: |================================== 00:15 ==================================| 100.00% Suffix
# Total seconds passed: 14.5497


# No need to use try/catch without thread
bar = ProgressBar(total, use_thread=False, time_format='hh, mm ss')
for x in range(total):
    time.sleep(0.1)
    bar.iter()
# Progress: |================================== 00, 00 15 ===================================| 100.00%



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="awesome-progress-bar",
    version="1.6.4",
    author="Yoskutik",
    author_email="yoskutik@gmail.com",
    description="Progress bar for terminal",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/yoskutik/awesome_progress_bar",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3.4",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.4',
)